@@ -10,10 +10,12 @@ mod schema;
 
 pub mod executor;
 pub mod postgres;
+pub mod scheduler;
 pub mod worker_pool;
 
 pub use executor::*;
 pub use postgres::*;
+pub use scheduler::*;
 pub use worker_pool::*;
 
 #[doc(hidden)]
